@@ -16,18 +16,22 @@ function run(){
   if [ "$1" == "--append" ]; then
     local append=1
     shift
+  else
+    local append=0
   fi
   local action="$1"
   shift
   echo "ACTION: ${action}"
   echo "  RUN:  $*"
   if [ "$append" == "1" ]; then
+    touch ./op.log
     echo "*** RUN:  $*" >> ./op.log
     "$@" >> ./op.log 2>&1
   else
     "$@" &> ./op.log
   fi
   local rc=$?
+  pwd
 
   if [ "$rc" == 0 ]; then
     echo "  RESULT: success"
@@ -62,7 +66,7 @@ Notes:
 1) additional args passed directly to tox
 2) additional args specify desired tox test environments to run
 3) additional args passed directly to pytest
-4) automatically generates coverage data first 
+4) automatically generates coverage data first
 5) additional args passed directly to setup.py
 6) extra args ignored.
 EOF
@@ -70,12 +74,13 @@ EOF
 }
 
 function activate_venv(){
+  # shellcheck disable=SC1091
   if ! . "${VENV}/bin/activate"; then
     errexit "Error: can't activate python3 environment."
   fi
 }
 function has_untracked_files(){
-  [ "$(git status --porcelain 2>/dev/null | grep -Ec '^(M| M|\?\?|u) ')" != 0 ]
+  [ "$(git status --porcelain 2>/dev/null | grep -Ec '^(M| [MD]|\?\?|u) ')" != 0 ]
 }
 function require_working_directory_clean(){
   if has_untracked_files; then
@@ -86,9 +91,89 @@ function require_working_directory_clean(){
     true
   fi
 }
+function fix_wheel(){
+  # shellcheck disable=SC2155
+  local wheel=$( readlink -f "${1}")
+  if [ ! -f "$wheel" ]; then
+    echo "Wheel file $wheel does not exist!" 1>&2
+    return 1
+  fi
+  
+  # shellcheck disable=SC2155
+  local wheel_base=$(basename "$wheel")
+  local zip_base="${wheel_base/.whl/.zip}"
+  # shellcheck disable=SC2155
+  local workdir=$(mktemp -d)
+  local zipfile="${workdir}/${zip_base}"
+  echo "* Copying wheel to temporary directory."
+  if ! cp -v "${wheel}" "${zipfile}"; then
+    echo "Unable to copy wheel file." 1>&2
+    return 1
+  fi
+  echo "* Entering temporary directory."
+  if ! pushd "${workdir}" &> /dev/null; then
+    echo "Unable to enter temporary directory." 1>&2
+    return 1
+  fi
+  echo "* Extracting wheel zip file."
+  if ! unzip "${zipfile}"; then
+    echo "Unable to extract wheel contents." 1>&2
+    # shellcheck disable=SC2164
+    popd
+    return 1
+  fi
+  echo "* Finding and updating nspkg.pth files."
+  if ! find . -iname '*-nspkg.pth' -exec sed -i 's/;/\n/g' '{}' \;; then
+    echo "Can not modify nspkg.pth files." 1>&2
+    # shellcheck disable=SC2164
+    popd
+    return 1
+  fi
+  echo "* Removing the copied wheel archive."
+  if ! rm "${zipfile}"; then
+    echo "Unable to remove no-longer-needed zipfile." 1>&2
+    # shellcheck disable=SC2164
+    popd
+    return 1
+  fi
+  echo "* Zipping up fixed wheel contents."
+  if ! zip -r "${zip_base}" .; then
+    echo "Unable to archive fixed wheel contents." 1>&2
+    # shellcheck disable=SC2164
+    popd
+    return 1
+  fi
+  echo "* Copying fixed wheel zip file back to it's original location."
+  if ! cp -v "${zipfile}" "${wheel}" ; then
+    echo "Unable to copy the fixed wheel to it's original location." 1>&2
+    # shellcheck disable=SC2164
+    popd
+    return 1
+  fi
+  echo "* Removing the working directory."
+  if ! rm -rfv "${workdir}"; then
+    echo "Unable to remove temporary directory." 1>&2
+    # shellcheck disable=SC2164
+    popd
+    return 1
+  fi
+
+  # shellcheck disable=SC2164
+  popd
+  return 0
+}
 
 function do_action(){
   case "$1" in
+    fix-wheel)
+      shift
+      run "Fix wheel NSPKG.pth format." fix_wheel "$@"
+    ;;
+    fix-wheels)
+      for filename in dist/*.whl; do
+        do_action fix-wheel "$filename"
+      done
+    ;;
     rebuild-venv)
       local interpreter=${2-python3}
       run "Delete python3 environment." rm -rf "${VENV}"
@@ -98,13 +183,13 @@ function do_action(){
     build-venv)
       local interpreter=${2-python3}
       if [ ! -d "${VENV}" ]; then
-        run "Create python3 environment" "${interpreter}" -m venv "${VENV}"          
+        run "Create python3 environment" "${interpreter}" -m venv "${VENV}"
       fi
       activate_venv
-      run "Upgrade python3 pip"                pip install --upgrade pip            
+      run "Upgrade python3 pip"                pip install --upgrade pip
       run "Install development requirements"   pip install -r "requirements-dev.txt"
-      run "Install runtime requirements"       pip install -r "requirements.txt"    
-      run "Install python project"             python "${FOLDER}/setup.py" develop  
+      run "Install runtime requirements"       pip install -r "requirements.txt"
+      run "Install python project"             python "${FOLDER}/setup.py" develop
     ;;
 
     test)
@@ -115,6 +200,7 @@ function do_action(){
     test-envs)
       shift
       envs="$*"
+      # shellcheck disable=SC2086
       tox -vv -e ${envs// /,}
     ;;
 
